/***********************************************************************
 * ImageQuantizer
 * Interface related to the quantization an image.
 ***********************************************************************/

#ifndef _REDUCTION_H_
# define _REDUCTION_H_


/***********************************************************************
 * Given an histogram h of size n, where n is the number of gray levels,
 * this function computes k-1 thresholds (p_1, ... p_{k-1}) and
 * k levels (v_1, ... v_k), with k <= n, such that the resulting mapping
 * function g(i) minimizes the squared error \sum_{i=0}^{n-1} h[i](i-g(i))^2.
 *
 * PARAMETERS
 * histogram        - The histogram vector (h)
 * histogramLength  - Size of the histogram vector (n)
 * reductionLength  - The number of thresholds to compute (k-1)
 * thresholds       - An allocated vector of size k-1 where the computed
 *                    thresholds (p_1, ..., p_{k-1}) will be stored
 * levels           - An allocated vector of size k where the computed levels
 *                    (v_1, ..., v_k) will be stored
 ***********************************************************************/
void computeReduction(const size_t* histogram, size_t histogramLength,
                      size_t reductionLength, size_t* thresholds,
                      uint16_t* levels);


#endif // !_REDUCTION_H_

